@@ -97,6 +97,11 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         'vip_network_id': loadbalancer.vip_network_id,
                         'admin_state_up': admin_state_up}
 
+        if not isinstance(loadbalancer.additional_vips,
+                          o_datamodels.UnsetType):
+            request_info[constants.ADDITIONAL_VIPS] = \
+                loadbalancer.additional_vips
+
         request = {'type': ovn_const.REQ_TYPE_LB_CREATE,
                    'info': request_info}
         self._ovn_helper.add_request(request)
@@ -260,9 +265,22 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         _, ovn_lb = self._ovn_helper._find_ovn_lb_by_pool_id(member.pool_id)
         if not ovn_lb:
             return False
-        lb_vip = ovn_lb.external_ids[ovn_const.LB_EXT_IDS_VIP_KEY]
-        return netaddr.IPNetwork(lb_vip).version != (
-            netaddr.IPNetwork(member.address).version)
+        lb_vips = [ovn_lb.external_ids.get(
+            ovn_const.LB_EXT_IDS_VIP_KEY)]
+        if ovn_const.LB_EXT_IDS_ADDIT_VIP_KEY in ovn_lb.external_ids:
+            lb_vips.extend(ovn_lb.external_ids.get(
+                ovn_const.LB_EXT_IDS_ADDIT_VIP_KEY).split(','))
+
+        # NOTE(froyo): Allow mixing member IP version when VIP LB and any
+        # additional vip is also mixing version
+        vip_version = netaddr.IPNetwork(lb_vips[0]).version
+        vips_mixed = any(netaddr.IPNetwork(vip).version != vip_version
+                         for vip in lb_vips if vip)
+
+        if vips_mixed:
+            return False
+        else:
+            return vip_version != (netaddr.IPNetwork(member.address).version)
 
     def member_create(self, member):
         # Validate monitoring options if present
@@ -474,13 +492,23 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         :return: a tuple that contains the VIP provider dictionary and a list
                  of additional VIP dictionaries
         """
-        # TODO(gthiemonge): implement additional_vip_dicts
         try:
-            port = self._ovn_helper.create_vip_port(
-                project_id, lb_id, vip_dict)
-            vip_dict[constants.VIP_PORT_ID] = port['id']
+            port, additional_ports = self._ovn_helper.create_vip_port(
+                project_id, lb_id, vip_dict, additional_vip_dicts)
+            vip_dict[constants.VIP_PORT_ID] = port.id
             vip_dict[constants.VIP_ADDRESS] = (
                 port['fixed_ips'][0]['ip_address'])
+
+            additional_vip_port_dict = []
+            for additional_port in additional_ports:
+                additional_vip_port_dict.append({
+                    'port_id': additional_port['id'],
+                    constants.NETWORK_ID:
+                        additional_port[constants.NETWORK_ID],
+                    constants.SUBNET_ID:
+                        additional_port['fixed_ips'][0]['subnet_id'],
+                    'ip_address': additional_port['fixed_ips'][0]['ip_address']
+                })
         except Exception as e:
             kwargs = {}
             for attr in ('details', 'message'):
@@ -491,7 +519,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                     break
             raise driver_exceptions.DriverError(
                 **kwargs)
-        return vip_dict, []
+        return vip_dict, additional_vip_port_dict
 
     def _validate_hm_support(self, hm, action='create'):
         if not self._is_health_check_supported():
